@@ -1,16 +1,16 @@
 /*
- 
+
  Copyright (C) 2006 NTT DATA Corporation
- 
+
  This program is free software; you can redistribute it and/or
- Modify it under the terms of the GNU General Public License 
+ Modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation, version 2.
- 
+
  This program is distributed in the hope that it will be
- useful, but WITHOUT ANY WARRANTY; without even the implied 
- warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+ useful, but WITHOUT ANY WARRANTY; without even the implied
+ warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  PURPOSE.  See the GNU General Public License for more details.
- 
+
  */
 
 package com.clustercontrol.jobmanagement.dao;
@@ -47,40 +47,42 @@ import com.clustercontrol.jobmanagement.ejb.entity.JobStartTimeInfoPK;
  * @see com.clustercontrol.jobmanagement.dao.JobStartTimeInfoDAO
  */
 public class JobStartTimeInfoDAOImpl implements JobStartTimeInfoDAO {
-	
+
 	/** ログ出力のインスタンス。 */
-	protected static Log m_log = LogFactory.getLog(JobStartTimeInfoDAOImpl.class);
-	
+	private static Log m_log = LogFactory.getLog(JobStartTimeInfoDAOImpl.class);
+
+	@Override
 	public void init() {
 	}
-	
-	/** 
+
+	/**
 	 * SELECT文を発行します。
 	 * 引数で指定されたプライマリキーで検索し、取得したデータベースの内容をEntity Beanに反映します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobStartTimeInfoDAO#load(com.clustercontrol.jobmanagement.ejb.entity.JobStartTimeInfoPK, com.clustercontrol.jobmanagement.ejb.entity.JobStartTimeInfoBean)
 	 */
+	@Override
 	public void load(JobStartTimeInfoPK pk, JobStartTimeInfoBean ejb) throws EJBException {
 		m_log.debug("load() start : " + pk.toString());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		ResultSet res = null;
-		
+
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_start_time_info WHERE session_id = ? AND job_id = ? AND jobunit_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
-			
+
 			stmt.setString(1, pk.getSession_id());
 			stmt.setString(2, pk.getJob_id());
 			stmt.setString(3, pk.getJobunit_id());
-			
+
 			res = stmt.executeQuery();
-			
+
 			if (res.next()) {
 				//取得した値をBeanにセット
 				ejb.setJob_id(res.getString("job_id"));
@@ -114,21 +116,22 @@ public class JobStartTimeInfoDAOImpl implements JobStartTimeInfoDAO {
 		}
 		m_log.debug("load() end : " + pk.toString());
 	}
-	
+
 	/**
 	 * UPDATE文を発行します。
 	 * 引数で指定されたEntity Beanの内容でデータベースを更新します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobStartTimeInfoDAO#store(com.clustercontrol.jobmanagement.ejb.entity.JobStartTimeInfoBean)
 	 */
+	@Override
 	public void store(JobStartTimeInfoBean ejb) throws EJBException {
 		m_log.debug("store() start : sessionId=" + ejb.getSession_id()
 				+ ", jobunitId=" + ejb.getJobunit_id()
 				+ ", jobId=" + ejb.getJob_id());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
-		
+
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			//SQL文の定義
@@ -138,17 +141,17 @@ public class JobStartTimeInfoDAOImpl implements JobStartTimeInfoDAO {
 			sql.append("WHERE session_id = ? ");
 			sql.append("AND job_id = ? ");
 			sql.append("AND jobunit_id = ? ");
-			
+
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
-			
+
 			stmt.setTime(1, ejb.getStart_time());
 			stmt.setString(2, ejb.getSession_id());
 			stmt.setString(3, ejb.getJob_id());
 			stmt.setString(4, ejb.getJobunit_id());
-			
+
 			int row = stmt.executeUpdate();
-			
+
 			if (row != 1) {
 				String msg = "result row is not 1";
 				m_log.error("store() error : " + ejb.getSession_id() + ", "
@@ -157,8 +160,8 @@ public class JobStartTimeInfoDAOImpl implements JobStartTimeInfoDAO {
 			}
 		} catch (SQLException e) {
 			m_log.error("store() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException");
+					+ ", jobunitId=" + ejb.getJobunit_id()
+					+ ", jobId=" + ejb.getJob_id() + " SQLException");
 			throw new EJBException(e.getMessage());
 		} finally {
 			// コネクション、結果セット、プリペアドステートメントのクローズ
@@ -171,8 +174,8 @@ public class JobStartTimeInfoDAOImpl implements JobStartTimeInfoDAO {
 				}
 			} catch (SQLException e1) {
 				m_log.error("store() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException");
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id() + " SQLException");
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -180,41 +183,42 @@ public class JobStartTimeInfoDAOImpl implements JobStartTimeInfoDAO {
 				+ ", jobunitId=" + ejb.getJobunit_id()
 				+ ", jobId=" + ejb.getJob_id());
 	}
-	
+
 	/**
 	 * DELETE文を発行します。
 	 * 引数で指定されたプライマリキーでデータベースから削除します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobStartTimeInfoDAO#remove(com.clustercontrol.jobmanagement.ejb.entity.JobStartTimeInfoPK)
 	 */
+	@Override
 	public void remove(JobStartTimeInfoPK pk) throws RemoveException, EJBException {
 		m_log.debug("remove() start : " + pk.toString());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義
 			String sql = "DELETE FROM cc_job_start_time_info WHERE session_id = ? AND job_id = ? AND jobunit_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
-			
+
 			stmt.setString(1, pk.getSession_id());
 			stmt.setString(2, pk.getJob_id());
 			stmt.setString(3, pk.getJobunit_id());
-			
+
 			int row = stmt.executeUpdate();
-			
+
 			if (row != 1 ) {
 				String msg = "result row is not 1";
 				m_log.error("remove() error : " + pk.toString() + " SQLException" + msg);
-				throw new EJBException(msg);	
+				throw new EJBException(msg);
 			}
 		} catch (SQLException e) {
 			m_log.error("remove() error : " + pk.toString() + " SQLException");
 			throw new EJBException(e.getMessage());
-			
+
 		} finally {
 			try {
 				if(stmt != null){
@@ -230,18 +234,19 @@ public class JobStartTimeInfoDAOImpl implements JobStartTimeInfoDAO {
 		}
 		m_log.debug("remove() end : " + pk.toString());
 	}
-	
+
 	/**
 	 * INSERT文を発行します。
 	 * 引数で指定されたEntity Beanの内容をデータベースに挿入し、プライマリキーを返します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobStartTimeInfoDAO#create(com.clustercontrol.jobmanagement.ejb.entity.JobStartTimeInfoBean)
 	 */
+	@Override
 	public JobStartTimeInfoPK create(JobStartTimeInfoBean ejb) throws CreateException, EJBException {
 		m_log.debug("create() start : sessionId=" + ejb.getSession_id()
 				+ ", jobunitId=" + ejb.getJobunit_id()
 				+ ", jobId=" + ejb.getJob_id());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		JobStartTimeInfoPK pk;
@@ -255,33 +260,33 @@ public class JobStartTimeInfoDAOImpl implements JobStartTimeInfoDAO {
 			sql.append("start_time, ");
 			sql.append("jobunit_id) ");
 			sql.append("VALUES (?,?,?,?)");
-			
+
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
-			
+
 			stmt.setString(1, ejb.getSession_id());
 			stmt.setString(2, ejb.getJob_id());
 			stmt.setTime(3, ejb.getStart_time());
 			stmt.setString(4, ejb.getJobunit_id());
-			
+
 			int row =	stmt.executeUpdate();
 			pk = new JobStartTimeInfoPK(
 					ejb.getSession_id(),
 					ejb.getJobunit_id(),
 					ejb.getJob_id());
-			
+
 			if (row != 1) {
 				String msg = "result row is not 1";
 				m_log.error("create() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException");
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id() + " SQLException");
 				throw new EJBException(msg);
 			}
 		} catch (SQLException e) {
 			if(e.getSQLState().equals("23505")){
 				m_log.error("create() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException" + "DuplicateKeyException ");
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id() + " SQLException" + "DuplicateKeyException ");
 				throw new DuplicateKeyException(e.getMessage());
 			}
 			throw new CreateException(e.getMessage());
@@ -295,8 +300,8 @@ public class JobStartTimeInfoDAOImpl implements JobStartTimeInfoDAO {
 				}
 			} catch (SQLException e1) {
 				m_log.error("create() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException");
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id() + " SQLException");
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -305,7 +310,7 @@ public class JobStartTimeInfoDAOImpl implements JobStartTimeInfoDAO {
 				+ ", jobId=" + ejb.getJob_id());
 		return pk;
 	}
-	
+
 	/**
 	 * 全件取得するSELECT文を発行します。
 	 * 取得したデータのプライマリキーをコレクションに格納し返します。
@@ -313,22 +318,23 @@ public class JobStartTimeInfoDAOImpl implements JobStartTimeInfoDAO {
 	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobStartTimeInfoBean#ejbFindAll()
 	 * @see com.clustercontrol.jobmanagement.dao.JobStartTimeInfoDAO#findAll()
 	 */
+	@Override
 	public Collection findAll() throws FinderException {
 		m_log.debug("findAll() start : ");
-		
+
 		ArrayList<JobStartTimeInfoPK> ret = new ArrayList<JobStartTimeInfoPK>();
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		ResultSet res = null;
 		try {
-			conn = ConnectionManager.getConnectionManager().getConnection();	
+			conn = ConnectionManager.getConnectionManager().getConnection();
 			//SQL文の定義
 			String sql = "SELECT session_id, jobunit_id, job_id FROM cc_job_start_time_info";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
-			
+
 			while(res.next()) {
 				JobStartTimeInfoPK pk= new JobStartTimeInfoPK(
 						res.getString("session_id"),
@@ -336,7 +342,7 @@ public class JobStartTimeInfoDAOImpl implements JobStartTimeInfoDAO {
 						res.getString("job_id"));
 				ret.add(pk);
 			}
-			
+
 		} catch (SQLException e) {
 			m_log.error("findAll() error :  SQLException");
 			throw new EJBException(e.getMessage());
@@ -357,7 +363,7 @@ public class JobStartTimeInfoDAOImpl implements JobStartTimeInfoDAO {
 		m_log.debug("findAll() end : ");
 		return ret;
 	}
-	
+
 	/**
 	 * 1件取得するSELECT文を発行します。
 	 * 引数で指定されたプライマリキーで、データベースを検索します。
@@ -365,26 +371,27 @@ public class JobStartTimeInfoDAOImpl implements JobStartTimeInfoDAO {
 	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobStartTimeInfoBean#ejbFindByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobStartTimeInfoPK)
 	 * @see com.clustercontrol.jobmanagement.dao.JobStartTimeInfoDAO#findByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobStartTimeInfoPK)
 	 */
+	@Override
 	public JobStartTimeInfoPK findByPrimaryKey(JobStartTimeInfoPK pk) throws FinderException {
 		m_log.debug("findByPrimaryKey() start : " + pk.toString());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		ResultSet res = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義
 			String sql = "SELECT session_id, jobunit_id, job_id FROM cc_job_start_time_info WHERE session_id = ? AND job_id = ? AND jobunit_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
-			
+
 			stmt.setString(1, pk.getSession_id());
 			stmt.setString(2, pk.getJob_id());
 			stmt.setString(3, pk.getJobunit_id());
-			
+
 			res = stmt.executeQuery();
-			
+
 			if (res.next()) {
 				return pk;
 			} else {
@@ -410,7 +417,7 @@ public class JobStartTimeInfoDAOImpl implements JobStartTimeInfoDAO {
 			m_log.debug("findByPrimaryKey() end : " + pk.toString());
 		}
 	}
-	
+
 	/**
 	 * ジョブ待ち条件時刻情報をジョブ待ち条件時刻マスタから作成します。
 	 * 
@@ -423,17 +430,17 @@ public class JobStartTimeInfoDAOImpl implements JobStartTimeInfoDAO {
 	 */
 	public void makeSession(String sessionId, String jobunitId, Collection jobs) throws CreateException{
 		m_log.debug("makeSession() start : sessionId=" + sessionId + ", jobunitId=" + jobunitId);
-		
-		Connection conn=null; 
+
+		Connection conn=null;
 		Connection connMaster = null;
 		PreparedStatement stmt=null;
 		PreparedStatement stmtMaster= null;
 		String jobId = null;
-		
+
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			connMaster = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義(INSERT)
 			StringBuilder sql = new StringBuilder();
 			sql.append("INSERT INTO cc_job_start_time_info (");
@@ -442,7 +449,7 @@ public class JobStartTimeInfoDAOImpl implements JobStartTimeInfoDAO {
 			sql.append("start_time, ");
 			sql.append("jobunit_id) ");
 			sql.append("VALUES (?,?,?,?)");
-			
+
 			//SQL文のセット(INSERT)
 			stmt = conn.prepareStatement(sql.toString());
 			stmt.setString(1,sessionId);
@@ -450,23 +457,23 @@ public class JobStartTimeInfoDAOImpl implements JobStartTimeInfoDAO {
 
 			//SQL文の定義(マスタ検索)
 			String sql_mst = "SELECT * FROM cc_job_start_time_mst WHERE job_id = ? AND jobunit_id = ?";
-			
+
 			//SQL文のセット(マスタ検索)
 			stmtMaster = connMaster.prepareStatement(sql_mst);
-			
+
 			Iterator it = jobs.iterator();
 			while(it.hasNext()){
 				//ジョブID取得
 				Hashtable ht = (Hashtable)it.next();
 				jobId = (String)ht.get("jobId");
-				
+
 				//SQL文のセット(マスタ検索)
 				stmtMaster.setString(1, jobId);
 				stmtMaster.setString(2, jobunitId);
-				
+
 				//SQL実行(マスタ検索)
 				ResultSet resMaster = stmtMaster.executeQuery();
-				
+
 				if (resMaster.next()) {
 					//SQL文のセット(INSERT)
 					stmt.setString(2, resMaster.getString("job_id"));
@@ -487,8 +494,8 @@ public class JobStartTimeInfoDAOImpl implements JobStartTimeInfoDAO {
 		} catch (SQLException e) {
 			if(e.getSQLState().equals("23505")){
 				m_log.error("makeSession() error : sessionId=" + sessionId
-								+ ", jobunitId=" + jobunitId
-								+ ", jobId" + jobId+ " SQLException" + "DuplicateKeyException ");
+						+ ", jobunitId=" + jobunitId
+						+ ", jobId" + jobId+ " SQLException" + "DuplicateKeyException ");
 				throw new DuplicateKeyException(e.getMessage());
 			}
 			throw new CreateException(e.getMessage());
@@ -508,12 +515,12 @@ public class JobStartTimeInfoDAOImpl implements JobStartTimeInfoDAO {
 				}
 			} catch (SQLException e1) {
 				m_log.error("makeSession() error : sessionId=" + sessionId
-								+ ", jobunitId=" + jobunitId
-								+ ", jobId" + jobId + " SQLException");
+						+ ", jobunitId=" + jobunitId
+						+ ", jobId" + jobId + " SQLException");
 				throw new EJBException(e1.getMessage());
 			}
 		}
 		m_log.debug("makeSession() end : sessionId=" + sessionId
-								+ ", jobunitId=" + jobunitId);
+				+ ", jobunitId=" + jobunitId);
 	}
 }
