@@ -1,23 +1,21 @@
 /*
- 
+
 Copyright (C) 2006 NTT DATA Corporation
- 
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
-*/
+
+ */
 
 package com.clustercontrol.monitor.run.factory;
 
 import java.sql.Timestamp;
-import java.text.ParseException;
-import java.util.Calendar;
 import java.util.Collection;
 import java.util.Date;
 
@@ -37,23 +35,26 @@ import javax.transaction.TransactionManager;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.quartz.SchedulerException;
 
-import com.clustercontrol.HinemosUnknownException;
-import com.clustercontrol.MonitorNotFoundException;
-import com.clustercontrol.NotifyNotFoundException;
-import com.clustercontrol.accesscontrol.factory.AccessLock;
-import com.clustercontrol.bean.ValidConstant;
+import com.clustercontrol.fault.HinemosUnknown;
+import com.clustercontrol.fault.MonitorNotFound;
+import com.clustercontrol.fault.NotifyNotFound;
+import com.clustercontrol.bean.HinemosModuleConstant;
+import com.clustercontrol.bean.YesNoConstant;
+import com.clustercontrol.commons.bean.SettingUpdateInfo;
+import com.clustercontrol.commons.scheduler.TriggerSchedulerException;
+import com.clustercontrol.custom.util.CustomManagerUtil;
 import com.clustercontrol.monitor.run.bean.MonitorInfo;
 import com.clustercontrol.monitor.run.ejb.entity.MonitorInfoLocal;
-import com.clustercontrol.monitor.run.ejb.entity.MonitorInfoPK;
 import com.clustercontrol.monitor.run.ejb.entity.MonitorInfoUtil;
 import com.clustercontrol.notify.ejb.entity.MonitorStatusLocal;
+import com.clustercontrol.notify.ejb.entity.MonitorStatusPK;
 import com.clustercontrol.notify.ejb.entity.MonitorStatusUtil;
 import com.clustercontrol.notify.ejb.entity.NotifyHistoryLocal;
 import com.clustercontrol.notify.ejb.entity.NotifyHistoryUtil;
 import com.clustercontrol.notify.ejb.session.NotifyControllerLocal;
 import com.clustercontrol.notify.ejb.session.NotifyControllerUtil;
+import com.clustercontrol.notify.util.MonitorResultStatusUpdater;
 import com.clustercontrol.util.apllog.AplLogger;
 
 /**
@@ -61,89 +62,91 @@ import com.clustercontrol.util.apllog.AplLogger;
  * <p>
  * 監視種別（真偽値，数値，文字列）の各クラスで継承してください。
  *
- * @version 3.0.0
+ * @version 4.0.0
  * @since 2.0.0
  */
 abstract public class ModifyMonitor {
 	/** ログ出力のインスタンス。 */
-	protected static Log m_log = LogFactory.getLog( ModifyMonitor.class );
-	
+	private static Log m_log = LogFactory.getLog( ModifyMonitor.class );
+
 	/** 監視情報のローカルコンポーネント。 */
 	protected MonitorInfoLocal m_monitor;
-	
+
 	/** 監視情報。 */
 	protected MonitorInfo m_monitorInfo;
-	
+
 	/** ファシリティ変更フラグ。 */
-	protected boolean m_isModifyFacilityId;
-	
+	protected boolean m_isModifyFacilityId = false;
+
 	/** 実行間隔変更フラグ。 */
-	protected boolean m_isModifyRunInterval;
-	
-	/**有効/無効変更フラグ。 */
-	protected boolean m_isModifyValid;
-	
+	protected boolean m_isModifyRunInterval = false;
+
+	/** 有効への変更フラグ。 */
+	protected boolean m_isModifyEnableFlg = false;
+
+	/**
+	 * スケジュール実行種別を返します。
+	 */
+	protected abstract String getTriggerType();
+
+	/**
+	 * スケジュール実行の遅延時間を返します。
+	 */
+	protected abstract int getDelayTime();
+
 	/**
 	 * トランザクションを開始し、引数で指定された監視情報を変更します。
 	 * 
 	 * @param info 監視情報
 	 * @param user 最終変更ユーザ
 	 * @return 変更に成功した場合、</code> true </code>
-	 * @throws CreateException
-	 * @throws RemoveException
-	 * @throws SchedulerException
-	 * @throws ParseException
-	 * @throws NamingException
-	 * @throws NotSupportedException
-	 * @throws HeuristicMixedException
-	 * @throws HeuristicRollbackException
-	 * @throws RollbackException
-	 * @throws InvalidTransactionException
-	 * @throws IllegalStateException
-	 * @throws SystemException
-	 * @throws HinemosUnknownException 
-	 * @throws NotifyNotFoundException 
-	 * @throws MonitorNotFoundException 
+	 * @throws InvalidSetting
 	 */
-	public boolean modify(MonitorInfo info, String user) throws CreateException, RemoveException, SchedulerException, ParseException, NamingException, NotSupportedException, HeuristicMixedException, HeuristicRollbackException, RollbackException, InvalidTransactionException, IllegalStateException, SystemException, NotifyNotFoundException, HinemosUnknownException, MonitorNotFoundException {
-    	
-		//アクセスロック
-    	AccessLock.lock(AccessLock.MONITOR);
-    	
+	public boolean modify(MonitorInfo info, String user) throws CreateException, RemoveException, NamingException, NotSupportedException, HeuristicMixedException, HeuristicRollbackException, RollbackException, InvalidTransactionException, IllegalStateException, SystemException, NotifyNotFound, HinemosUnknown, MonitorNotFound, TriggerSchedulerException {
+
 		m_monitorInfo = info;
-		
+
 		TransactionManager tm = null;
-//		Transaction tx = null;
-//		Transactionの利用を取りやめたため、関連箇所ふくめコメントアウトした : uchiyama
 		Transaction oldTx = null;
 		boolean result = false;
-		
-		try 
+
+		try
 		{
 			// TransactionManagerを取得
 			InitialContext context = new InitialContext();
 			tm = (TransactionManager)context.lookup("java:/TransactionManager");
-			
-			// 実行中のスレッドがトランザクションに関連付けられている場合は、トランザクションを退避 
+
+			// 実行中のスレッドがトランザクションに関連付けられている場合は、トランザクションを退避
 			if(tm.getTransaction() != null){
 				oldTx = tm.suspend();
 			}
-			
+
 			try{
 				// トランザクション開始
 				if(tm.getTransaction() == null){
-					tm.begin();	
-//					tx = tm.getTransaction();
+					tm.begin();
 				}
-				
+
 				// 監視情報を変更
 				result = modifyMonitorInfo(user);
 				if(result){
 					// コミット
-//					tx.commit();
 					tm.commit();
 				}
-			
+
+				if (info != null) {
+					if (HinemosModuleConstant.MONITOR_CUSTOM.equals(info.getMonitorTypeId())) {
+						// read-committedのため、commit後に外部コンポーネントに通知する
+						CustomManagerUtil.broadcastConfigured();
+					}
+					if (HinemosModuleConstant.MONITOR_SYSTEMLOG.equals(info.getMonitorTypeId())) {
+						SettingUpdateInfo.getInstance().setSystemLogMonitorUpdateTime(System.currentTimeMillis());
+					}
+					if (HinemosModuleConstant.MONITOR_SNMPTRAP.equals(info.getMonitorTypeId())) {
+						SettingUpdateInfo.getInstance().setSnmptrapMonitorUpdateTime(System.currentTimeMillis());
+					}
+				}
+
 			} catch(NotSupportedException e){
 				outputLog(e, "modify()");
 				throw e;
@@ -162,12 +165,6 @@ abstract public class ModifyMonitor {
 			}
 			finally{
 				// トランザクション関連の例外が発生した場合は、ロールバック
-//				if(tx != null){
-//					if(!result){
-//						tx.rollback();
-//					}
-//					tx = null;
-//				}
 				if(tm.getTransaction() != null){
 					if(!result){
 						tm.rollback();
@@ -176,12 +173,12 @@ abstract public class ModifyMonitor {
 			}
 		}
 		finally{
-			
+
 			// 一時停止していたトランザクションを再開
 			if(oldTx != null){
 				try{
 					tm.resume(oldTx);
-					
+
 				} catch(InvalidTransactionException e){
 					outputLog(e, "modify()");
 					throw e;
@@ -196,7 +193,7 @@ abstract public class ModifyMonitor {
 		}
 		return result;
 	}
-	
+
 	/**
 	 * 判定情報を変更し、監視情報に設定します。
 	 * <p>
@@ -206,11 +203,11 @@ abstract public class ModifyMonitor {
 	 * @throws CreateException
 	 * @throws RemoveException
 	 * @throws NamingException
-	 * @throws HinemosUnknownException
-	 * @throws NotifyNotFoundException 
+	 * @throws HinemosUnknown
+	 * @throws NotifyNotFound
 	 */
-	public abstract boolean modifyJudgementInfo() throws CreateException, RemoveException, NamingException, HinemosUnknownException, NotifyNotFoundException;
-	
+	protected abstract boolean modifyJudgementInfo() throws CreateException, RemoveException, NamingException, HinemosUnknown, NotifyNotFound;
+
 	/**
 	 * チェック条件情報を変更し、監視情報に設定します。
 	 * <p>
@@ -221,32 +218,8 @@ abstract public class ModifyMonitor {
 	 * @throws FinderException
 	 * @throws NamingException
 	 */
-	public abstract boolean modifyCheckInfo() throws CreateException, FinderException, NamingException;
-	
-	/**
-     * Quartzに登録するスケジュールカレンダを返します。
-     * <p>
-     * デフォルトでは、<code>null</code>を返します。<BR>
-     * Quartzに<code>SimpleTrigger</code>で監視情報を登録する場合は、<code>null</code>を返します。
-     * <code>CronTrigger</code>で登録する場合は、サブクラスで引数で指定された周期を基にカレンダを作成し返します。
-     * 
-     * @param interval 周期（秒）
-     * @return スケジュール
-     * 
-     * @see com.clustercontrol.monitor.run.factory.ModifySchedule#modifySchedule(MonitorInfo, Calendar)
-     */
-	public Calendar getCalendar(int interval) {
-		
-		// 日時を設定
-//        Calendar calendar = Calendar.getInstance();
-//        calendar.set(Calendar.HOUR_OF_DAY, 0);
-//        calendar.set(Calendar.MINUTE, 0);
-//        calendar.set(Calendar.SECOND, interval);
-//        
-//        return calendar;
-		return null;
-	}
-	
+	protected abstract boolean modifyCheckInfo() throws CreateException, FinderException, NamingException;
+
 	/**
 	 * 監視情報を作成します。
 	 * <p>
@@ -262,118 +235,115 @@ abstract public class ModifyMonitor {
 	 * @return 更新に成功した場合、true
 	 * @throws CreateException
 	 * @throws RemoveException
-	 * @throws SchedulerException
-	 * @throws ParseException
 	 * @throws NamingException
-	 * @throws HinemosUnknownException 
-	 * @throws NotifyNotFoundException 
-	 * @throws MonitorNotFoundException 
+	 * @throws HinemosUnknown
+	 * @throws NotifyNotFound
+	 * @throws MonitorNotFound
+	 * @throws TriggerSchedulerException
 	 */
-	protected boolean modifyMonitorInfo(String user) throws CreateException, RemoveException, SchedulerException, ParseException, NamingException, NotifyNotFoundException, HinemosUnknownException, MonitorNotFoundException{
+	protected boolean modifyMonitorInfo(String user) throws CreateException, RemoveException, NamingException, NotifyNotFound, HinemosUnknown, MonitorNotFound, TriggerSchedulerException{
+		Timestamp now = new Timestamp(new Date().getTime());
 
-		try 
-		{
-			// 監視情報を取得
-			MonitorInfoPK pk = new MonitorInfoPK(m_monitorInfo.getMonitorId(), m_monitorInfo.getMonitorTypeId());
-			m_monitor = MonitorInfoUtil.getLocalHome().findByPrimaryKey(pk);
+		try{
+			// 監視情報を設定
+			m_monitor = MonitorInfoUtil.getLocalHome().findByPrimaryKey(m_monitorInfo.getMonitorId());
 
+			// ファシリティIDが変更されているか
 			if(!m_monitorInfo.getFacilityId().equals(m_monitor.getFacilityId())){
 				m_isModifyFacilityId = true;
 			}
+			// 監視/収集間隔が変更されているか
 			if(m_monitorInfo.getRunInterval() != m_monitor.getRunInterval().intValue()){
 				m_isModifyRunInterval = true;
 			}
-			if(!m_isModifyRunInterval){
-				int oldValid = new SelectSchedule().getValid(m_monitorInfo.getMonitorTypeId(), m_monitorInfo.getMonitorId());
-				if(m_monitorInfo.getValid() != oldValid){
-					m_isModifyValid = true;
-				}
+			// 監視/収集無効から有効(監視or収集のいずれか1つでも)に変更されているか
+			if(m_monitor.getMonitorFlg().intValue() == YesNoConstant.TYPE_NO &&
+					m_monitor.getCollectorFlg().intValue() == YesNoConstant.TYPE_NO &&
+					(m_monitorInfo.getMonitorFlg() == YesNoConstant.TYPE_YES || m_monitorInfo.getCollectorFlg() == YesNoConstant.TYPE_YES)){
+				m_isModifyEnableFlg = true;
 			}
-			
-			// 監視情報を設定
+			m_log.debug("modifyMonitorInfo() m_isModifyFacilityId = " + m_isModifyFacilityId
+					+ ", m_isModifyRunInterval = " + m_isModifyRunInterval
+					+ ", m_isModifyEnableFlg = " + m_isModifyEnableFlg);
+
 			m_monitor.setDescription(m_monitorInfo.getDescription());
 			if(m_isModifyFacilityId)
 				m_monitor.setFacilityId(m_monitorInfo.getFacilityId());
 			if(m_isModifyRunInterval)
 				m_monitor.setRunInterval(m_monitorInfo.getRunInterval());
-			m_monitor.setTimeout(m_monitorInfo.getTimeout());
+			m_monitor.setDelayTime(getDelayTime());
+			m_monitor.setTriggerType(getTriggerType());
 			m_monitor.setCalendarId(m_monitorInfo.getCalendarId());
-			m_monitor.setMonitorBlock(m_monitorInfo.getMonitorBlock());
-			m_monitor.setDeterminationId(m_monitorInfo.getDeterminationId());
 			m_monitor.setFailurePriority(m_monitorInfo.getFailurePriority());
 			m_monitor.setApplication(m_monitorInfo.getApplication());
-			m_monitorInfo.setFailureMessageId(m_monitorInfo.getFailureMessageId());
-			m_monitorInfo.setFailureMessage(m_monitorInfo.getFailureMessage());
 			m_monitor.setNotifyGroupId(m_monitorInfo.getNotifyGroupId());
-			m_monitor.setUpdateDate(new Timestamp(new Date().getTime()));
+			m_monitor.setMonitorFlg(m_monitorInfo.getMonitorFlg());
+			m_monitor.setCollectorFlg(m_monitorInfo.getCollectorFlg());
+			m_monitor.setItemName(m_monitorInfo.getItemName());
+			m_monitor.setMeasure(m_monitorInfo.getMeasure());
+			m_monitor.setUpdateDate(now);
 			m_monitor.setUpdateUser(user);
-			
+
 			NotifyControllerLocal nc = NotifyControllerUtil.getLocalHome().create();
 			nc.modifyNotifyRelation(m_monitorInfo.getNotifyId(), m_monitorInfo.getNotifyGroupId());
-			
+
 			// 判定情報を設定
 			if(modifyJudgementInfo()){
-			
+
 				// チェック条件情報を設定
 				if(modifyCheckInfo()){
-					
-					// Quartzに登録
-					if(m_isModifyRunInterval || m_isModifyValid){
-						ModifySchedule quartz = new ModifySchedule();
-						quartz.modifySchedule(m_monitorInfo, getCalendar(m_monitorInfo.getRunInterval()));
-						
-						// 監視設定を無効にした場合
-						if(m_monitorInfo.getValid() == ValidConstant.TYPE_INVALID){
-							// この監視設定の監視結果状態を削除する
-							Collection<MonitorStatusLocal> statusList = 
-								MonitorStatusUtil.getLocalHome().findByPluginIdAndMonitorId(m_monitor.getMonitorTypeId(), m_monitor.getMonitorId());
-							for(MonitorStatusLocal status : statusList){
-								status.remove();
-							}
-							
-							// 監視を無効にした場合は、その監視設定の結果として通知された通知履歴を削除する
-							Collection<NotifyHistoryLocal> historyList = NotifyHistoryUtil.getLocalHome().findByPluginIdAndMonitorId(m_monitor.getMonitorTypeId(), m_monitor.getMonitorId());
-							for(NotifyHistoryLocal history : historyList){
-								history.remove();
-							}
-						}
+
+					// Quartzの登録情報を変更
+					new ModifySchedule().updateSchedule(m_monitorInfo.getMonitorId());
+
+					// この監視設定の監視結果状態を削除する
+					Collection<MonitorStatusLocal> statusList =
+						MonitorStatusUtil.getLocalHome().findByPluginIdAndMonitorId(m_monitor.getMonitorTypeId(), m_monitor.getMonitorId());
+					for(MonitorStatusLocal status : statusList){
+						MonitorStatusPK pk = (MonitorStatusPK)status.getPrimaryKey();
+						status.remove();
+						MonitorResultStatusUpdater.removeCache(pk);
 					}
+
+					// この監視設定の結果として通知された通知履歴を削除する
+					Collection<NotifyHistoryLocal> historyList = NotifyHistoryUtil.getLocalHome().findByPluginIdAndMonitorId(m_monitor.getMonitorTypeId(), m_monitor.getMonitorId());
+					for(NotifyHistoryLocal history : historyList){
+						history.remove();
+					}
+
 					return true;
 				}
 			}
 			return false;
-			
+
 		} catch (CreateException e) {
 			outputLog(e, "modifyMonitorInfo()");
 			throw e;
 		} catch (FinderException e) {
 			outputLog(e, "modifyMonitorInfo()");
-			throw new MonitorNotFoundException(e.getMessage(), e);
+			throw new MonitorNotFound(e.getMessage(), e);
 		} catch (RemoveException e) {
 			outputLog(e, "modifyMonitorInfo()");
 			throw e;
-		} catch (SchedulerException e) {
-			outputLog(e, "modifyMonitorInfo()");
-			throw e;
-		} catch (ParseException e) {
+		} catch (TriggerSchedulerException e) {
 			outputLog(e, "modifyMonitorInfo()");
 			throw e;
 		} catch (NamingException e) {
 			outputLog(e, "modifyMonitorInfo()");
 			throw e;
-		} 
+		}
 	}
 
 	/**
-     * アプリケーションログにログを出力します。
-     * 
+	 * アプリケーションログにログを出力します。
+	 * 
 	 * @param e 例外
 	 * @param method メソッド名
 	 */
 	private void outputLog(Exception e, String method) {
 		AplLogger apllog = new AplLogger("MON", "mon");
 		String[] args = {m_monitorInfo.getMonitorTypeId(), m_monitorInfo.getMonitorId() };
-        apllog.put("SYS", "008", args);
-        m_log.debug(method + ":" + e.getMessage());
+		apllog.put("SYS", "008", args);
+		m_log.debug(method + ":" + e.getMessage());
 	}
 }
