@@ -1,16 +1,16 @@
 /*
- 
+
  Copyright (C) 2006 NTT DATA Corporation
- 
+
  This program is free software; you can redistribute it and/or
- Modify it under the terms of the GNU General Public License 
+ Modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation, version 2.
- 
+
  This program is distributed in the hope that it will be
- useful, but WITHOUT ANY WARRANTY; without even the implied 
- warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+ useful, but WITHOUT ANY WARRANTY; without even the implied
+ warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  PURPOSE.  See the GNU General Public License for more details.
- 
+
  */
 
 package com.clustercontrol.notify.ejb.entity;
@@ -39,32 +39,32 @@ import com.clustercontrol.notify.bean.NotifyTypeConstant;
  *     primkey-field="notifyId"
  *     schema="NotifyInfo"
  *     cmp-version="2.x"
- *     data-source="java:/HinemosDS"
- *         
- * @jboss.depends name="jboss.jca:service=DataSourceBinding,name=HinemosDS"
+ *     data-source="java:/DefaultDS"
+ * 
+ * @jboss.depends name="jboss.jca:service=DataSourceBinding,name=DefaultDS"
  * 
  * @jboss.container-configuration
  *    name="Hinemos Config CMP 2.x EntityBean"
- *    
+ * 
  * @jboss.method-attributes
  *    pattern="get*"
  *    read-only="true"
- *    
+ * 
  * @jboss.persistence
- *    datasource="java:/HinemosDS"
+ *    datasource="java:/DefaultDS"
  *    datasource-mapping="PostgreSQL 8.0"
  *    table-name="public.cc_notify_info"
  *    create-table="false"
  *    remove-table="false"
  *    alter-table="false"
- *           
- * @ejb.persistence 
+ * 
+ * @ejb.persistence
  *     table-name="cc_notify_info"
- *     
- * @ejb.finder 
- *     query="SELECT OBJECT(a) FROM NotifyInfo as a"  
+ * 
+ * @ejb.finder
+ *     query="SELECT OBJECT(a) FROM NotifyInfo as a"
  *     signature="java.util.Collection findAll()"
- *     
+ * 
  * @ejb.finder
  *    query=""
  *    signature="java.util.Collection findAllOrderByNotifyId()"
@@ -76,28 +76,30 @@ import com.clustercontrol.notify.bean.NotifyTypeConstant;
  * @jboss.query
  *    query="SELECT OBJECT(a) FROM NotifyInfo as a ORDER BY a.notifyId"
  *    signature="java.util.Collection findAllOrderByNotifyId()"
- *           
+ * 
  * @ejb.permission
  *     unchecked="true"
- *     
+ * 
  * @ejb.pk class="java.lang.String"
  */
 public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 	/** ログ出力のインスタンス */
 	private static Log m_log = LogFactory.getLog( NotifyInfoBean.class );
-	
+
 	/* (非 Javadoc)
 	 * @see javax.ejb.EntityBean#setEntityContext(javax.ejb.EntityContext)
 	 */
+	@Override
 	public void setEntityContext(EntityContext ctx) throws EJBException, RemoteException {
 	}
-	
+
 	/* (非 Javadoc)
 	 * @see javax.ejb.EntityBean#unsetEntityContext()
 	 */
+	@Override
 	public void unsetEntityContext() throws EJBException, RemoteException {
 	}
-	
+
 	/**
 	 * 通知情報を生成します。
 	 * 
@@ -135,10 +137,10 @@ public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 			String regUser,
 			String updateUser,
 			Integer vaildFlg
-//			String useType	FIXME	 * @param useType 使用種別
-			) throws javax.ejb.CreateException {
-		
-		
+			//			String useType	FIXME	 * @param useType 使用種別
+	) throws javax.ejb.CreateException {
+
+
 		setNotifyId(notifyId);
 		setDescription(description);
 		setNotifyType(notifyType);
@@ -150,45 +152,50 @@ public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 		setRegUser(regUser);
 		setUpdateUser(updateUser);
 		setValidFlg(vaildFlg);
-//		setUseType(useType);
-		
+		//		setUseType(useType);
+
 		return null;
 	}
-	
 
 
+
+	@Override
 	public void ejbRemove() throws RemoveException, EJBException, RemoteException {
 	}
-	
+
+	@Override
 	public void ejbActivate() throws EJBException, RemoteException {
 	}
-	
+
+	@Override
 	public void ejbPassivate() throws EJBException, RemoteException {
 	}
-	
+
+	@Override
 	public void ejbLoad() throws EJBException, RemoteException {
 	}
-	
+
+	@Override
 	public void ejbStore() throws EJBException, RemoteException {
 	}
-	
+
 	/**
 	 * 通知IDを返します。
 	 * 
-	 * @ejb.persistent-field 
+	 * @ejb.persistent-field
 	 * @ejb.persistence
 	 *    column-name="notify_id"
 	 *     jdbc-type="VARCHAR"
 	 *     sql-type="VARCHAR(64)"
-	 *     read-only="false"
-	 * @ejb.pk-field 
-	 *
+	 * @ejb.pk-field
+	 * 
 	 * @ejb.interface-method
 	 * 
 	 * @return 通知ID
 	 */
+	@Override
 	public abstract String getNotifyId();
-	
+
 	/**
 	 * 通知IDを設定します。
 	 * 
@@ -197,23 +204,22 @@ public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 	 * @param notifyId 通知ID
 	 */
 	public abstract void setNotifyId(String notifyId);
-	
+
 	/**
 	 * 説明を返します。
 	 * 
-	 * @ejb.persistent-field 
+	 * @ejb.persistent-field
 	 * @ejb.persistence
 	 *    column-name="description"
 	 *     jdbc-type="VARCHAR"
 	 *     sql-type="VARCHAR(256)"
-	 *     read-only="false"
-	 *
+	 * 
 	 * @ejb.interface-method
 	 * 
 	 * @return 説明
 	 */
 	public abstract String getDescription();
-	
+
 	/**
 	 * 説明を設定します。
 	 * 
@@ -222,26 +228,25 @@ public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 	 * @param description 説明
 	 */
 	public abstract void setDescription(String description);
-	
-    /**
-     * 通知タイプを返します。
-     *
-     * @ejb.persistent-field 
+
+	/**
+	 * 通知タイプを返します。
+	 *
+	 * @ejb.persistent-field
 	 * @ejb.persistence
 	 *    column-name="notify_type"
 	 *     jdbc-type="SMALLINT"
 	 *     sql-type="smallint"
-	 *     read-only="false"
 	 *
-	 * @ejb.interface-method 
-     * 
-     * @return notifyType 通知タイプ
-     *
-     * @see com.clustercontrol.bean.ValidConstant
-     */
+	 * @ejb.interface-method
+	 * 
+	 * @return notifyType 通知タイプ
+	 *
+	 * @see com.clustercontrol.bean.ValidConstant
+	 */
 	public abstract Integer getNotifyType();
-	
-	
+
+
 	/**
 	 * 通知タイプを設定します。
 	 *
@@ -250,24 +255,23 @@ public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 	 * @param notifyType
 	 */
 	public abstract void setNotifyType(Integer notifyType);
-	
-	
+
+
 	/**
 	 * 初回通知するまでのカウント（この数以上同じ重要度の監視結果が連続した場合に始めて通知）を返します。
 	 * 
-	 * @ejb.persistent-field 
+	 * @ejb.persistent-field
 	 * @ejb.persistence
 	 *    column-name="initial_count"
 	 *     jdbc-type="SMALLINT"
 	 *     sql-type="smallint"
-	 *     read-only="false"
-	 *  
+	 * 
 	 * @ejb.interface-method
 	 * 
 	 * @return 初回通知するまでのカウント
 	 */
 	public abstract Integer getInitialCount();
-	
+
 	/**
 	 * 初回通知するまでのカウント（この数以上同じ重要度の監視結果が連続した場合に始めて通知）を設定します。
 	 * 
@@ -276,23 +280,22 @@ public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 	 * @param initialCount 初回通知するまでのカウント
 	 */
 	public abstract void setInitialCount(Integer initialCount);
-	
+
 	/**
 	 * 再通知種別を返します。
 	 * 
-	 * @ejb.persistent-field 
+	 * @ejb.persistent-field
 	 * @ejb.persistence
 	 *    column-name="renotify_type"
 	 *     jdbc-type="SMALLINT"
 	 *     sql-type="smallint"
-	 *     read-only="false"
-	 *  
+	 * 
 	 * @ejb.interface-method
 	 * 
 	 * @return 再通知種別
 	 */
 	public abstract Integer getRenotifyType();
-	
+
 	/**
 	 * 再通知種別を設定します。
 	 * 
@@ -301,23 +304,22 @@ public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 	 * @param renotifyType 再通知種別
 	 */
 	public abstract void setRenotifyType(Integer renotifyType);
-	
+
 	/**
 	 * 再通知抑制期間を返します。
 	 * 
-	 * @ejb.persistent-field 
+	 * @ejb.persistent-field
 	 * @ejb.persistence
 	 *    column-name="renotify_period"
 	 *     jdbc-type="SMALLINT"
 	 *     sql-type="smallint"
-	 *     read-only="false"
-	 *  
+	 * 
 	 * @ejb.interface-method
 	 * 
 	 * @return 再通知抑制期間（分）
 	 */
 	public abstract Integer getRenotifyPeriod();
-	
+
 	/**
 	 * 再通知抑制期間を設定します。
 	 * 
@@ -326,23 +328,22 @@ public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 	 * @param renotifyPeriod 再通知抑制期間（分）
 	 */
 	public abstract void setRenotifyPeriod(Integer renotifyPeriod);
-	
+
 	/**
 	 * 作成日時を返します。
 	 * 
-	 * @ejb.persistent-field 
+	 * @ejb.persistent-field
 	 * @ejb.persistence
 	 *    column-name="reg_date"
 	 *     jdbc-type="TIMESTAMP"
 	 *     sql-type="TIMESTAMP"
-	 *     read-only="false"
-	 *  
+	 * 
 	 * @ejb.interface-method
 	 * 
 	 * @return 作成日時
 	 */
 	public abstract Timestamp getRegDate();
-	
+
 	/**
 	 * 作成日時を設定します。
 	 * 
@@ -351,24 +352,23 @@ public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 	 * @param regDate 作成日時
 	 */
 	public abstract void setRegDate(Timestamp regDate);
-	
-	
+
+
 	/**
 	 * 最終変更日時を返します。
 	 * 
-	 * @ejb.persistent-field 
+	 * @ejb.persistent-field
 	 * @ejb.persistence
 	 *    column-name="update_date"
 	 *     jdbc-type="TIMESTAMP"
 	 *     sql-type="TIMESTAMP"
-	 *     read-only="false"
-	 *  
+	 * 
 	 * @ejb.interface-method
 	 * 
 	 * @return 最終変更日時
 	 */
 	public abstract Timestamp getUpdateDate();
-	
+
 	/**
 	 * 最終変更日時を設定します。
 	 * 
@@ -377,43 +377,41 @@ public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 	 * @param updateDate 最終変更日時
 	 */
 	public abstract void setUpdateDate(Timestamp updateDate);
-	
-	
+
+
 	/**
 	 *更新ユーザを返します。
 	 * 
-	 * @ejb.persistent-field 
+	 * @ejb.persistent-field
 	 * @ejb.persistence
 	 *    column-name="update_user"
 	 *     jdbc-type="VARCHAR"
 	 *     sql-type="VARCHAR(64)"
-	 *     read-only="false"
-	 *
+	 * 
 	 * @ejb.interface-method
 	 * 
 	 * @return updateUser 更新ユーザ
 	 */
 	public abstract String getUpdateUser();
-	
+
 	/**
 	 * 最終変更ユーザを設定します。
 	 * 
-	 * @ejb.interface-method 
+	 * @ejb.interface-method
 	 * @param updateUser 更新ユーザ
 	 */
 	public abstract void setUpdateUser(String updateUser);
-	
-	
-     /**
+
+
+	/**
 	 *作成ユーザを返します。
 	 * 
-	 * @ejb.persistent-field 
+	 * @ejb.persistent-field
 	 * @ejb.persistence
 	 *    column-name="reg_user"
 	 *     jdbc-type="VARCHAR"
 	 *     sql-type="VARCHAR(64)"
-	 *     read-only="false"
-	 *
+	 * 
 	 * @ejb.interface-method
 	 * 
 	 * @return updateUser 作成ユーザ
@@ -423,59 +421,55 @@ public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 	/**
 	 * 作成ユーザを設定します。
 	 * 
-	 * @ejb.interface-method 
+	 * @ejb.interface-method
 	 * @param regUser 作成ユーザ
 	 */
 	public abstract void setRegUser(String regUser);
 
-	
+
 	/**
 	 * 有効無効フラグを返します。
 	 * 
-	 * @ejb.persistent-field 
+	 * @ejb.persistent-field
 	 * @ejb.persistence
 	 *    column-name="valid_flg"
 	 *     jdbc-type="SMALLINT"
 	 *     sql-type="smallint"
-	 *     read-only="false"
-	 *  
+	 * 
 	 * @ejb.interface-method
 	 * 
 	 * @return vaildFlg 有効無効フラグ
 	 */
+	@Override
 	public abstract Integer getValidFlg();
 
 	/**
-     * 有効無効フラグを設定します。
-     * 
-     * @ejb.interface-method 
+	 * 有効無効フラグを設定します。
+	 * 
+	 * @ejb.interface-method
 	 * @param vaildFlg 有効無効フラグ
 	 */
 	public abstract void setValidFlg(Integer validFlg);
-	
+
 	/**
 	 * このCMPのデータをフィールドとして持つDataオブジェクト（NotifyInfoData）を返します。
 	 * 
 	 * @ejb.interface-method
 	 * 
-	 * @jboss.method-attributes read-only="true"
-	 * 
 	 * @return Returns Dataオブジェクト（NotifyInfoData）
 	 */
 	public abstract NotifyInfoData getData();
-	
+
 	/**
 	 * 重要度毎の設定を返します。
 	 * 
 	 * @ejb.interface-method
 	 * 
-	 * @jboss.method-attributes read-only="true"
-	 * 
 	 * @return Returns 重要度毎の設定
 	 */
 	public NotifyDetail getNotifyDetail(int priority){
 		m_log.debug("getNotifyDetail() " + getNotifyId() + ",  priority = " + priority);
-		
+
 		switch (getNotifyType()) {
 		case NotifyTypeConstant.TYPE_EVENT:
 			Collection<NotifyEventInfoLocal> events = getNotifyEventInfo();
@@ -545,32 +539,32 @@ public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 		return null;
 	}
 
-// FIXME
-//	/**
-//	 * 使用種別を返します。
-//	 * 
-//	 * @ejb.persistent-field 
-//	 * @ejb.persistence
-//	 *    column-name="use_type"
-//	 *     jdbc-type="VARCHAR"
-//	 *     sql-type="VARCHAR(64)"
-//	 *     read-only="false"
-//	 *  
-//	 * @ejb.interface-method
-//	 * 
-//	 * @return useType 使用種別
-//	 */
-//	public abstract String getUseType();
-//
-//	/**
-//     * 使用種別を設定します。
-//     * 
-//     * @ejb.interface-method 
-//	 * @param useType 使用種別
-//	 */
-//	public abstract void setUseType(String useType);
-	
-	
+	// FIXME
+	//	/**
+	//	 * 使用種別を返します。
+	//	 *
+	//	 * @ejb.persistent-field
+	//	 * @ejb.persistence
+	//	 *    column-name="use_type"
+	//	 *     jdbc-type="VARCHAR"
+	//	 *     sql-type="VARCHAR(64)"
+	//	 *     read-only="false"
+	//	 *
+	//	 * @ejb.interface-method
+	//	 *
+	//	 * @return useType 使用種別
+	//	 */
+	//	public abstract String getUseType();
+	//
+	//	/**
+	//     * 使用種別を設定します。
+	//     *
+	//     * @ejb.interface-method
+	//	 * @param useType 使用種別
+	//	 */
+	//	public abstract void setUseType(String useType);
+
+
 	//	==========================================
 	//	 CMR fields
 	//	==========================================
@@ -579,7 +573,7 @@ public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 	 * 
 	 * @ejb.interface-method view-type="local"
 	 * 
-	 * @ejb.relation 
+	 * @ejb.relation
 	 *    name="NotifyInfo-NotifyEventInfo"
 	 *    role-name="NotifyInfo-NotifyEventInfo(single)"
 	 *    target-cascade-delete="true"
@@ -587,7 +581,7 @@ public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 	 * @return 通知イベント情報のコレクション
 	 */
 	public abstract Collection<NotifyEventInfoLocal> getNotifyEventInfo();
-	
+
 	/**
 	 * 通知イベント情報を設定します。
 	 * 
@@ -596,13 +590,13 @@ public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 	 * @param collection 通知イベント情報のコレクション
 	 */
 	public abstract void setNotifyEventInfo(Collection<NotifyEventInfoLocal> collection);
-	
+
 	/**
 	 * 通知ステータス情報を返します。
 	 * 
 	 * @ejb.interface-method view-type="local"
 	 * 
-	 * @ejb.relation 
+	 * @ejb.relation
 	 *    name="NotifyInfo-NotifyStatusInfo"
 	 *    role-name="NotifyInfo-NotifyStatusInfo(single)"
 	 *    target-cascade-delete="true"
@@ -611,7 +605,7 @@ public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 	 * 
 	 */
 	public abstract Collection<NotifyStatusInfoLocal> getNotifyStatusInfo();
-	
+
 	/**
 	 * 通知ステータス情報を設定します。
 	 * 
@@ -620,21 +614,21 @@ public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 	 * @param collection 通知ステータス情報のコレクション
 	 */
 	public abstract void setNotifyStatusInfo(Collection<NotifyStatusInfoLocal> collection);
-	
-	
+
+
 	/**
 	 * 通知メール情報を返します。
 	 *
 	 * @ejb.interface-method view-type="local"
-	 *  
-	 * @ejb.relation 
+	 * 
+	 * @ejb.relation
 	 *    name="NotifyInfo-NotifyMailInfo"
 	 *    role-name="NotifyInfo-NotifyMailInfo(single)"
 	 *    target-cascade-delete="true"
 	 * 
 	 */
 	public abstract Collection<NotifyMailInfoLocal> getNotifyMailInfo();
-	
+
 	/**
 	 * 通知メール情報を設定します。
 	 * 
@@ -643,13 +637,13 @@ public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 	 * @param collection 通知メール情報のコレクション
 	 */
 	public abstract void setNotifyMailInfo(Collection<NotifyMailInfoLocal> collection);
-	
+
 	/**
 	 * 通知ジョブ情報を返します。
 	 *
 	 * @ejb.interface-method view-type="local"
 	 * 
-	 * @ejb.relation 
+	 * @ejb.relation
 	 *    name="NotifyInfo-NotifyJobInfo"
 	 *    role-name="NotifyInfo-NotifyJobInfo(single)"
 	 *    target-cascade-delete="true"
@@ -657,7 +651,7 @@ public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 	 * retrun 通知ジョブ情報のコレクション
 	 */
 	public abstract Collection<NotifyJobInfoLocal> getNotifyJobInfo();
-	
+
 	/**
 	 * 通知ジョブ情報を設定します。
 	 * 
@@ -666,8 +660,8 @@ public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 	 * @param collection 通知ジョブ情報のコレクション
 	 */
 	public abstract void setNotifyJobInfo(Collection<NotifyJobInfoLocal> collection);
-	
-	
+
+
 	/**
 	 * 通知ログエスカレーション情報を返します。
 	 *
@@ -681,7 +675,7 @@ public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 	 * retrun 通知ログエスカレーション情報のコレクション
 	 */
 	public abstract Collection<NotifyLogEscalateInfoLocal> getNotifyLogEscalateInfo();
-	
+
 	/**
 	 * 通知ログエスカレーション情報を設定します。
 	 * 
@@ -690,7 +684,7 @@ public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 	 * @param collection 通知ログエスカレーション情報のコレクション
 	 */
 	public abstract void setNotifyLogEscalateInfo(Collection<NotifyLogEscalateInfoLocal> collection);
-	
+
 	/**
 	 * 通知コマンド情報を返します。
 	 *
@@ -704,7 +698,7 @@ public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 	 * retrun 通知ログエスカレーション情報のコレクション
 	 */
 	public abstract Collection<NotifyCommandInfoLocal> getNotifyCommandInfo();
-	
+
 	/**
 	 * 通知コマンド情報を設定します。
 	 * 
@@ -714,29 +708,6 @@ public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 	 */
 	public abstract void setNotifyCommandInfo(Collection<NotifyCommandInfoLocal> collection);
 
-	/**
-	 * 該当のエンティティに関連している通知履歴を取得します。
-	 * 
-	 * @ejb.interface-method view-type="local"
-	 * 
-	 * @ejb.relation 
-	 *    name="NotifyInfo-NotifyHistory"
-	 *    role-name="NotifyInfo-NotifyHistory(single)"
-	 *    target-cascade-delete="true"
-	 * 
-	 * @return 通知履歴のコレクション
-	 */
-	public abstract Collection<NotifyHistoryLocal> getNotifyHistory();
-	
-	/**
-	 * 通該当のエンティティに関連している通知履歴を設定します。
-	 * 
-	 * @ejb.interface-method view-type="local"
-	 * 
-	 * @param collection 通知履歴のコレクション
-	 */
-	public abstract void setNotifyHistory(Collection<NotifyHistoryLocal> collection);
-	
 	/**
 	 * 該当のエンティティに関連している通知関連情報を取得します。
 	 * 
@@ -750,7 +721,7 @@ public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 	 * @return 通知関連情報のコレクション
 	 */
 	public abstract Collection<NotifyRelationInfoLocal> getNotifyRelationInfo();
-	
+
 	/**
 	 * 通該当のエンティティに関連している通知履歴を設定します。
 	 * 
@@ -759,5 +730,5 @@ public abstract class NotifyInfoBean implements EntityBean, NotifyDetail {
 	 * @param collection 通知関連情報のコレクション
 	 */
 	public abstract void setNotifyRelationInfo(Collection<NotifyRelationInfoLocal> collection);
-	
+
 }
