@@ -3,12 +3,12 @@
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
 
  */
@@ -26,6 +26,7 @@ import java.util.ArrayList;
 import java.util.Date;
 import java.util.List;
 import java.util.Locale;
+import java.util.Map;
 
 import javax.ejb.FinderException;
 import javax.naming.NamingException;
@@ -33,12 +34,12 @@ import javax.naming.NamingException;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.bean.ExecFacilityConstant;
-import com.clustercontrol.bean.OutputBasicInfo;
-import com.clustercontrol.bean.SyslogFacilityConstant;
-import com.clustercontrol.bean.SyslogSeverityConstant;
 import com.clustercontrol.commons.util.HinemosProperties;
+import com.clustercontrol.notify.bean.ExecFacilityConstant;
 import com.clustercontrol.notify.bean.NotifyRequestMessage;
+import com.clustercontrol.notify.bean.OutputBasicInfo;
+import com.clustercontrol.notify.bean.SyslogFacilityConstant;
+import com.clustercontrol.notify.bean.SyslogSeverityConstant;
 import com.clustercontrol.notify.ejb.entity.NotifyLogEscalateInfoData;
 import com.clustercontrol.notify.ejb.entity.NotifyLogEscalateInfoLocal;
 import com.clustercontrol.notify.ejb.entity.NotifyLogEscalateInfoPK;
@@ -48,6 +49,7 @@ import com.clustercontrol.repository.ejb.entity.FacilityLocal;
 import com.clustercontrol.repository.ejb.entity.FacilityUtil;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerLocal;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerUtil;
+import com.clustercontrol.util.StringBinder;
 import com.clustercontrol.util.apllog.AplLogger;
 
 /**
@@ -58,7 +60,7 @@ import com.clustercontrol.util.apllog.AplLogger;
  */
 public class SendSyslog implements Notifier {
 	/** ログ出力のインスタンス。 */
-	protected static Log m_log = LogFactory.getLog( SendSyslog.class );
+	private static Log m_log = LogFactory.getLog( SendSyslog.class );
 
 	/** Syslogヘッダー部分時刻フォーマット。 */
 	private static final String HEADER_DATE_FORMAT = "MMM dd HH:mm:ss";
@@ -67,7 +69,7 @@ public class SendSyslog implements Notifier {
 	private static int MODE_HOSTNAME;
 	private static String HOSTNAME_DEFINED = null;
 	private static String HOSTNAME_SERVER = "unknownhost";
-	
+
 	private static final int MODE_HOSTNAME_DEFAULT = 0;
 	private static final int MODE_HOSTNAME_DEFINED = 1;
 	private static final int MODE_HOSTNAME_FACILITYID = 2;
@@ -79,7 +81,7 @@ public class SendSyslog implements Notifier {
 	static{
 		try {
 			String hostname = HinemosProperties.getProperty("common.manager.hostname");
-			
+
 			if (hostname == null) {
 				// undef hostname of syglog header
 				MODE_HOSTNAME = MODE_HOSTNAME_DEFAULT;
@@ -96,28 +98,29 @@ public class SendSyslog implements Notifier {
 				MODE_HOSTNAME = MODE_HOSTNAME_DEFINED;
 				HOSTNAME_DEFINED = hostname;
 			}
-			
+
 			HOSTNAME_SERVER = InetAddress.getLocalHost().getHostName();
-			
+
 			m_log.info("initialized syslog sender. (mode = " + MODE_HOSTNAME + ", hostname=" + HOSTNAME_DEFINED + ")");
-			
+
 		} catch (Exception e) {
 			m_log.warn(e.getMessage(), e);
-		} 
+		}
 	}
 
+	@Override
 	public void notify(NotifyRequestMessage message)
 	throws FinderException, NamingException {
 		if(m_log.isDebugEnabled()){
-			m_log.debug("notify() " + message); 
+			m_log.debug("notify() " + message);
 		}
 		sendlog(message.getOutputInfo(), message.getNotifyId());
 	}
-	
-	public void sendlog(OutputBasicInfo outputInfo, String notifyId)
+
+	private void sendlog(OutputBasicInfo outputInfo, String notifyId)
 	throws FinderException, NamingException {
 		if(m_log.isDebugEnabled()){
-			m_log.debug("sendlog() " + outputInfo); 
+			m_log.debug("sendlog() " + outputInfo);
 		}
 
 		// 該当する重要度の通知情報を取得する
@@ -128,7 +131,7 @@ public class SendSyslog implements Notifier {
 
 		// syslogの本文を作成
 		String message = getMessage(outputInfo, escalateInfoData);
-		
+
 		/**
 		 * 実行
 		 */
@@ -138,7 +141,7 @@ public class SendSyslog implements Notifier {
 			m_log.error(detailMsg);
 			internalErrorNotify(notifyId, "007", detailMsg);
 		}
-		
+
 		for(InetAddress address : ipAddresses){
 			try {
 				this.sendAfterConvertHostname(escalateInfoData, address, outputInfo.getFacilityId(), message);
@@ -150,7 +153,7 @@ public class SendSyslog implements Notifier {
 			}
 		}
 	}
-	
+
 	/**
 	 * 指定の通知情報をもとにsyslog送信先のノードを特定します。
 	 * NotifyLogEscalateInfoData の EscalateFacilityFlg が「ExecFacilityConstant.TYPE_GENERATION」にも
@@ -160,7 +163,7 @@ public class SendSyslog implements Notifier {
 	 * @param logEscalateInfo ログエスカレーション設定
 	 * @return 送信先ノードのIPアドレス
 	 */
-	public List<InetAddress> getIpAddresses(OutputBasicInfo outputInfo, NotifyLogEscalateInfoData logEscalateInfo){
+	private List<InetAddress> getIpAddresses(OutputBasicInfo outputInfo, NotifyLogEscalateInfoData logEscalateInfo){
 		// 送信先を特定
 		ArrayList<InetAddress> ipAddresses = new ArrayList<InetAddress>();
 		//リポジトリ(RepositoryControllerLocal)を取得
@@ -195,7 +198,7 @@ public class SendSyslog implements Notifier {
 					// 続けて次のノードを処理する
 				}
 			}
-			
+
 			return ipAddresses;
 		} catch (Exception e) {
 			m_log.error(e.getMessage(), e);
@@ -208,10 +211,12 @@ public class SendSyslog implements Notifier {
 	private String getMessage(OutputBasicInfo outputInfo, NotifyLogEscalateInfoData logEscalateInfo){
 		// 文字列を置換する
 		try {
-			return TextReplacer.substitution(logEscalateInfo.getEscalateMessage(), outputInfo);
+			Map<String, String> param = NotifyUtil.createParameter(outputInfo);
+			StringBinder binder = new StringBinder(param);
+			return binder.bindParam(logEscalateInfo.getEscalateMessage());
 		} catch (Exception e) {
 			m_log.error(e.getMessage(), e);
-			
+
 			// 例外が発生した場合は、置換前の文字列を返す
 			return logEscalateInfo.getEscalateMessage();
 		}
@@ -241,12 +246,12 @@ public class SendSyslog implements Notifier {
 	public void sendAfterConvertHostname(String ipAddress, int port, String facility, String severity, String facilityId, String message) {
 		// ローカル変数
 		String hostname = "";
-		
+
 		// メイン処理
 		hostname = getSyslogHeaderHost(facilityId);
 		send(ipAddress, port, facility, severity, hostname, message);
 	}
-	
+
 	/**
 	 * syslogでメッセージを送信する汎用メソッド
 	 * 
@@ -257,36 +262,36 @@ public class SendSyslog implements Notifier {
 	 * @param severity severity (emergency, alert, critical...)
 	 * @param message メッセージ文字列
 	 */
-	public void send(String ipAddress, int port, String facility, String severity, String hostname, String message) {
+	private void send(String ipAddress, int port, String facility, String severity, String hostname, String message) {
 		// ローカル変数
 		byte[] buf = new byte[LIMIT_SIZE];
 		InetAddress inetAddress = null;
 		SimpleDateFormat sdf = null;
-		
+
 		String timeStamp = null;
-		
+
 		int facilityInt = -1;
 		int severityInt = -1;
 		int priority = -1;
-		
+
 		String transferMsg = null;
-		
+
 		DatagramSocket soc = null;
 		DatagramPacket sendPacket = null;
-		
-		if (m_log.isDebugEnabled()) 
+
+		if (m_log.isDebugEnabled())
 			m_log.debug("start syslog transfer. (ipAddresss=" + ipAddress + ", port=" + port + ", "
 					+ "facility=" + facility + ", severity=" + severity + ", message=" + message + ")");
-		
+
 		// メイン処理
 		try {
 			// generate InetAddress
 			inetAddress = InetAddress.getByName(ipAddress);
-			
+
 			// generate timestamp of header
 			sdf = new SimpleDateFormat(HEADER_DATE_FORMAT, Locale.US);
 			timeStamp = sdf.format(new Date());
-			
+
 			// generate priority of header
 			facilityInt = SyslogFacilityConstant.stringToType(facility);
 			severityInt = SyslogSeverityConstant.stringToType(severity);
@@ -295,7 +300,7 @@ public class SendSyslog implements Notifier {
 				return;
 			}
 			priority = facilityInt + severityInt;
-			
+
 			// generate message
 			transferMsg = "<"+ priority + ">" + timeStamp + " " + hostname + " " + message;
 			// is over 1024 byte
@@ -303,19 +308,19 @@ public class SendSyslog implements Notifier {
 				buf = transferMsg.getBytes();
 				transferMsg = new String(buf, 0, LIMIT_SIZE);
 			}
-			
+
 			// send message
-			if (m_log.isDebugEnabled()) 
+			if (m_log.isDebugEnabled())
 				m_log.debug("sending syslog. (ipAddresss=" + ipAddress + ", port=" + port + ", "
 						+ "facility=" + facility + ", severity=" + severity + ", message=" + transferMsg + ")");
-			
+
 			soc = new DatagramSocket();
 			sendPacket = null;
 			buf = transferMsg.getBytes();
 			sendPacket = new DatagramPacket(buf, buf.length, inetAddress, port);
 			soc.send(sendPacket);
 			soc.close();
-			
+
 		} catch (UnknownHostException e) {
 			m_log.warn("sending syslog failure. syslog's host(" + ipAddress + ") is invalid.", e);
 		} catch (SocketException e) {
@@ -323,12 +328,12 @@ public class SendSyslog implements Notifier {
 		} catch (IOException e) {
 			m_log.warn("sending syslog failure.", e);
 		}
-		
-		if (m_log.isDebugEnabled()) 
+
+		if (m_log.isDebugEnabled())
 			m_log.debug("sended syslog successfully. (ipAddresss=" + ipAddress + ", port=" + port + ", "
 					+ "facility=" + facility + ", severity=" + severity + ", message=" + transferMsg + ")");
 	}
-	
+
 	/**
 	 * 設定ファイルに従って、syslogヘッダのホスト名として埋め込む文字列を生成する
 	 * @param facilityId 通知情報の対象ファシリティID
@@ -339,16 +344,16 @@ public class SendSyslog implements Notifier {
 		String hostname = "";
 		int mode = MODE_HOSTNAME;
 		boolean isBuildinScope = false;
-		
+
 		// メイン処理
 		if (m_log.isDebugEnabled()) m_log.debug("converting syglog hostname for '" + facilityId + "'. (mode = " + MODE_HOSTNAME + ")");
-		
+
 		if (FacilityTreeAttributeConstant.isBuiltinScope(facilityId)) {
 			// 組み込みスコープの場合は、マネージャのホスト名を埋め込む
 			if (m_log.isDebugEnabled()) m_log.debug("facility '" + facilityId + "' is buildin scope.");
 			isBuildinScope = true;
 		}
-		
+
 		switch (mode) {
 		case MODE_HOSTNAME_DEFINED :
 			hostname = HOSTNAME_DEFINED;
@@ -373,11 +378,11 @@ public class SendSyslog implements Notifier {
 		default :
 			hostname = HOSTNAME_SERVER;
 		}
-		
+
 		if (m_log.isDebugEnabled()) m_log.debug("use syslog hostname '" + hostname + "' for '" + facilityId + "'.");
 		return hostname;
 	}
-	
+
 	/**
 	 * 設定ファイルに従ってホスト名をヘッダに埋め込み、syslogパケットを送信する。<br>
 	 * 
@@ -390,12 +395,12 @@ public class SendSyslog implements Notifier {
 	private void sendAfterConvertHostname(NotifyLogEscalateInfoData logEscalateInfo, InetAddress ipAddress, String facilityId, String message) throws IOException {
 		// ローカル変数
 		String hostname = "";
-		
+
 		// メイン処理
 		hostname = getSyslogHeaderHost(facilityId);
 		send(logEscalateInfo, ipAddress, hostname, message);
 	}
-	
+
 	/**
 	 * syslogにメッセージを送る
 	 * 
@@ -408,11 +413,11 @@ public class SendSyslog implements Notifier {
 	private void send(NotifyLogEscalateInfoData logEscalateInfo, InetAddress ipAddress, String hostname, String message) throws IOException {
 		byte[] buf = new byte[LIMIT_SIZE];		// 送受信バッファ
 		int len;	// 送信文字数
-		
+
 		// ヘッダー部分のTIMESTAMPを生成
 		SimpleDateFormat sdf = new SimpleDateFormat(HEADER_DATE_FORMAT, Locale.US);
 		String headerTimeStamp = sdf.format(new Date());
-		
+
 		// 送信メッセージの作成
 		int syslogPriority = logEscalateInfo.getSyslogPriority() + logEscalateInfo.getSyslogFacility();
 		String sendMessage = "<"+ syslogPriority + ">" + headerTimeStamp + " " + hostname + " " + message;
@@ -439,6 +444,7 @@ public class SendSyslog implements Notifier {
 	/**
 	 * 通知失敗時の内部エラー通知を定義します
 	 */
+	@Override
 	public void internalErrorNotify(String notifyId, String msgID, String detailMsg) {
 		AplLogger apllog = new AplLogger("NOTIFY", "notify");
 		String[] args = { notifyId };
