@@ -1,17 +1,17 @@
 /*
-                                                                                                
+
 Copyright (C) 2008 NTT DATA Corporation
- 
+
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
- 
-*/
+
+ */
 
 package com.clustercontrol.poller;
 
@@ -25,30 +25,30 @@ import com.clustercontrol.sharedtable.DataTableNotFoundException;
 
 public class PollerManager {
 	private static Log m_log = LogFactory.getLog( PollerManager.class );
-	
+
 	private String m_managerName;
-	
+
 	/**
 	 * Key   : ポーラ識別情報
 	 * Value : ポーラ
 	 */
 	private ConcurrentHashMap<PollerInfo, PollingController> m_pollerTable;
-	
+
 	public PollerManager(String managerName){
 		m_managerName = managerName;
 		m_pollerTable = new ConcurrentHashMap<PollerInfo, PollingController>();
 	}
 
 	public PollingController createPoller(
-			String group, 
-			String facilityId, 
+			String group,
+			String facilityId,
 			boolean indexCheckFlg,
-			String tableGroup, 
+			String tableGroup,
 			String tableName)
 	throws NotInitializedException, DataTableNotFoundException {
 		if(m_log.isDebugEnabled()){
 			m_log.debug(
-					"create poller    " + 
+					"create poller    " +
 					"PollerGroup : " + group + ", " +
 					"FacilityId : " + facilityId + ", " +
 					"IndexCheckFlg : " + indexCheckFlg + ", " +
@@ -56,41 +56,23 @@ public class PollerManager {
 					"TableName : " + tableName
 			);
 		}
-		
+
 		// 収集情報、情報書き込み対象テーブル情報を格納したポーラを生成する
 		// この時点ではインスタンスを生成するだけでポーリングはスケジューリングしないため、
 		// ポーリングは実行されない
 		PollingController poller = new PollingController(
-						group, 
-						facilityId, 
-						facilityId, 
-						indexCheckFlg,
-						tableGroup, 
-						tableName);
-		
+				group,
+				facilityId,
+				facilityId,
+				indexCheckFlg,
+				tableGroup,
+				tableName);
+
 		// マップに登録する
 		m_pollerTable.put(new PollerInfo(group, facilityId), poller);
 		return poller;
 	}
-	
-	/**
-	 * 登録されているポーラを削除します。ポーラが実行中の場合は削除できません。
-	 * @param group ポーラグループ
-	 * @param facilityId ファシリティID
-	 */
-	public void removePoller(String group, String facilityId){
-		PollerInfo info = new PollerInfo(group, facilityId);
-		
-		PollingController poller = m_pollerTable.get(info);
-		
-		if(poller != null){
-			// 全ての収集名の収集を終了
-			poller.stopPollingAll();
-		}
-		
-		m_pollerTable.remove(new PollerInfo(group, facilityId));
-	}
-	
+
 	/**
 	 * 
 	 * @param pollerGroup
@@ -99,35 +81,27 @@ public class PollerManager {
 	public PollingController getPoller(String pollerGroup, String pollerName){
 		return m_pollerTable.get(new PollerInfo(pollerGroup, pollerName));
 	}
-	
-	/**
-	 * このインスタンスのマネージャ名を返します。
-	 * @return マネージャ名
-	 */
-	public String getManagerName() {
-		return m_managerName;
-	}
 
-	
+
 	/**
 	 * 管理しているポーラの情報を文字列で返します。
 	 * @return 管理しているテーブルの情報
 	 */
 	public String getPollerDebugInfo(){
 		String debugStr = "";
-		
+
 		Iterator<PollerInfo> itr = m_pollerTable.keySet().iterator();
-		
+
 		while(itr.hasNext()){
 			PollerInfo info = itr.next();
 			int minInterval = m_pollerTable.get(info).getPollingConfig().getMinPollingInterval();
 			debugStr = debugStr + info.getPollerGroup() + ", " + info.getPollerName() + ", " + minInterval+ "\n";
 			debugStr = debugStr + m_pollerTable.get(info).getPollingConfig().getDebugInfo();
 		}
-		
+
 		return debugStr;
 	}
-	
+
 	/**
 	 * 管理しているポーラを一意に識別するための情報を保持するクラス
 	 * HashMapのキーとして利用できるように equalsメソッドと hashCodeメソッドを実装
@@ -135,7 +109,7 @@ public class PollerManager {
 	private class PollerInfo{
 		private String m_pollerGroup;
 		private String m_pollerName;
-		
+
 		public PollerInfo(String pollerGroup, String pollerName){
 			m_pollerGroup = pollerGroup;
 			m_pollerName = pollerName;
@@ -148,12 +122,12 @@ public class PollerManager {
 		public String getPollerName() {
 			return m_pollerName;
 		}
-		
+
 		@Override
 		public boolean equals(Object other) {
 			if (other instanceof PollerInfo) {
 				PollerInfo info = (PollerInfo)other;
-				
+
 				if (this.m_pollerGroup == null && this.m_pollerName == null){
 					if (info.m_pollerGroup == null && info.m_pollerName == null){
 						return true;
