@@ -1,17 +1,17 @@
 /*
- 
+
 Copyright (C) 2006 NTT DATA Corporation
- 
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
-*/
+
+ */
 
 package com.clustercontrol.sql.factory;
 
@@ -19,9 +19,6 @@ import javax.ejb.FinderException;
 import javax.ejb.RemoveException;
 import javax.naming.NamingException;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
 import com.clustercontrol.monitor.run.factory.DeleteMonitor;
 import com.clustercontrol.sql.util.ControlSqlInfo;
 
@@ -32,15 +29,13 @@ import com.clustercontrol.sql.util.ControlSqlInfo;
  * @since 2.0.0
  */
 public class DeleteMonitorSql extends DeleteMonitor{
-	
-	protected static Log m_log = LogFactory.getLog( DeleteMonitorSql.class );
 
 	/* (non-Javadoc)
 	 * @see com.clustercontrol.monitor.run.factory.DeleteMonitor#deleteCheckInfo()
 	 */
 	@Override
-	public boolean deleteCheckInfo() throws FinderException, RemoveException, NamingException {
-		
+	protected boolean deleteCheckInfo() throws FinderException, RemoveException, NamingException {
+
 		// SQL監視情報を削除
 		ControlSqlInfo sql = new ControlSqlInfo(m_monitorId, m_monitorTypeId);
 		return sql.delete();
