@@ -28,6 +28,16 @@ then
 	ulimit -n ${JBOSS_FD_MAXNUM}
 fi
 
+if [ "x${NET_CORE_RMEM_MAX}" != "x" ]
+then
+	sysctl -w net.core.rmem_max=${NET_CORE_RMEM_MAX}
+fi
+
+if [ "x${NET_CORE_RMEM_DEF}" != "x" ]
+then
+	sysctl -w net.core.rmem_default=${NET_CORE_RMEM_DEF}
+fi
+
 ########################################
 #  Local Variable
 ########################################
@@ -43,6 +53,9 @@ JBOSS_CHECK_TIMEOUT=300
 # log file for monitor startup
 STARTUP_MONITOR_FILE=${HINEMOS_HOME}/var/log/startup.log
 
+# temporary export file dir
+EXPORT_TEMPORARY_DIR=${HINEMOS_HOME}/var/export
+
 ########################################
 #  Local Message
 ########################################
@@ -53,6 +66,7 @@ MSG_I002="JBoss configuration assigned"
 MSG_I003="removing temporally data (JMS) before JBoss start"
 MSG_I004="JBoss started"
 MSG_I005="starting Hinemos Manager(maintenance-mode)"
+MSG_I006="removing temporally data (Export) before JBoss start"
 
 # WARN
 MSG_W001="WARN : PID file(/var/run/snmptrapd.pid) is found. stop snmptrapd service."
@@ -86,7 +100,7 @@ do
 	case ${ARGS} in
 		-a)
 			# for HA Option
-			if [ ! -d ${JBOSS_HOME}/server/all ]
+			if [ ! -d ${JBOSS_HOME}/server/hinemos_ha ]
 			then
 				Logging "${MSG_E003}"
 				exit -5
@@ -148,20 +162,14 @@ fi
 #
 # set composition
 #
-if [ "x${OPTION}" = "x" ]
+if [ -d ${JBOSS_HOME}/server/hinemos_ha ]
 then
-	if [ -d ${JBOSS_HOME}/server/all ]
-	then
-		OPTION="-c all"
-	fi
+	CONFIGURATION="hinemos_ha"
+else
+	CONFIGURATION="hinemos"
 fi
 
-if [ "x${OPTION}" = "x-c all" ]
-then
-	Logging "${MSG_I002} : all"
-else
-	Logging "${MSG_I002} : default"
-fi
+Logging "${MSG_I002} : ${CONFIGURATION}"
 
 #
 # cleanup JMS
@@ -176,9 +184,12 @@ fi
 #
 # startup JBoss
 #
+echo && Logging "${MSG_I006}"
+rm -Rf ${EXPORT_TEMPORARY_DIR}/*
+
 echo && Logging "${MSG_I001}"
 
-nohup ${JBOSS_HOME}/bin/run_hinemos.sh ${OPTION} -b ${IP_ADDRESS} > ${HINEMOS_JBOSS_STDOUTERR} 2>&1 &
+nohup ${JBOSS_HOME}/bin/run_hinemos.sh ${OPTION} -c ${CONFIGURATION} -b ${IP_ADDRESS} > ${HINEMOS_JBOSS_STDOUTERR} 2>&1 &
 
 # wait for JBoss to start
 TIME_COUNT=0
@@ -194,7 +205,7 @@ do
 	
 	if [ -f ${STARTUP_MONITOR_FILE} ]
 	then
-		if [ `grep -a 'JBoss (MX MicroKernel).*Started' ${STARTUP_MONITOR_FILE} | wc -l` -gt 0 ]
+		if [ `grep -a 'JBoss (Microcontainer).*Started' ${STARTUP_MONITOR_FILE} | wc -l` -gt 0 ]
 		then
 			echo "done"
 			Logging "${MSG_I004}"
@@ -213,10 +224,4 @@ do
 	echo -n "."
 done
 
-if [ "x${JBOSS_STARTUP_WAIT}" = "xtrue" ]
-then
-	# restart syslogforward (for syslogforward reconnection)
-	/bin/kill -HUP `cat /var/run/syslog-ng.pid 2> /dev/null` 2> /dev/null
-fi
-
 exit 0
