@@ -59,6 +59,13 @@ done
 ##
 ## The file is forwarded from the server in the local.
 ##
+if [ -f ${FTP_PROC} ]; then
+    echo "FTP Command "$FTP_PROC" is installed."
+else
+    echo "FTP Command "$FTP_PROC" is not installed. Please install RPM package."
+    exit -1
+fi
+
 $EXPECT_PROC -c "
     set timeout 300
     spawn $FTP_PROC $FTP_HOST
@@ -83,7 +90,7 @@ $EXPECT_PROC -c "
     expect >
     send \"get $file\r\"
     expect {
-	OK.		{}	
+	complete.		{}	
 	Failed		{exit 1}
 	timeout		{exit 1}
     }
