@@ -31,6 +31,13 @@ echo $remotepath
 ##
 ## The rpm file is forwarded from the server in the local. 
 ##
+if [ -f ${FTP_PROC} ]; then
+    echo "FTP Command "$FTP_PROC" is installed."
+else
+    echo "FTP Command "$FTP_PROC" is not installed. Please install RPM package."
+    exit -1
+fi
+
 expect -c "
     set timeout 300
     spawn $FTP_PROC $FTP_HOST
@@ -47,7 +54,7 @@ expect -c "
     expect >
     send \"get $rpmfile\r\"
     expect {
-	OK.		{}	
+	complete.		{}	
 	Failed		{exit 1}
 	timeout		{exit 1}
     }
