@@ -11,17 +11,16 @@
 #MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #GNU General Public License for more details
 
-
-#設定情報読み込み
+# Set up information reading
 . /opt/hinemos/hinemos.cfg
 
-#ユーザチェック
+# User check
 if [ ! `whoami` = ${HINEMOS_JBOSS_USER} ]; then
-	echo "${HINEMOS_JBOSS_USER} ユーザで実行してください。"
+	echo "Please execute it by the ${HINEMOS_JBOSS_USER} user."
 	exit 1
 fi
 
-#引数チェック
+# Argument check
 REMOTE_USER=""
 if [ $# -eq 0 ]; then
 	REMOTE_USER="root"
@@ -31,10 +30,10 @@ else
 	echo "[Usage] : $0 [remot_user(default : root)]"
 	exit 1
 fi
-echo "監視対象ノードのユーザ${REMOTE_USER}へのセットアップを開始します。"
+echo "The setup of the node for the watch to user ${REMOTE_USER} begins."
 
 #
-#変数
+# Variables
 #
 SSH_KEYGEN="/usr/bin/ssh-keygen -t rsa"
 MKDIR=/bin/mkdir
@@ -42,22 +41,19 @@ CHMOD=/bin/chmod
 
 VERSION=`cat ${HINEMOS_HOME}/_version`
 
-echo ""
-echo "###################################################################"
-echo "###"
-echo "###              運用管理ソフトウェア Hinemos"
-echo "###            一括制御 セットアップスクリプト  Ver. ${VERSION}"
-echo "###"
-echo "###  Copyright (C) 2006 - 2009 NTT DATA Corporation."
-echo "###################################################################"
+echo
+echo "-------------------------------------------------------"
+echo "   Welcome to the Setup of the collective run function"
+echo "                     Hinemos  Version ${VERSION}"
+echo
+echo "       Copyright (C) since 2006 NTT DATA Corporation"
+echo "-------------------------------------------------------"
 
-
-
-#JBoss起動ユーザの認証用の公開鍵の作成
+# Making of public key for attestation of JBoss start user
 setup() {
     echo "" 
-    echo "${HINEMOS_JBOSS_USER} ユーザの認証用の公開鍵をパスフレーズなしで作成します。"
-    echo "よろしいですか? (Y/N default:Y)"
+    echo "The public key for the attestation of the ${HINEMOS_JBOSS_USER} user is made without the passphrase."
+    echo "Is it good? (Y/N default:Y)"
     while [ 1 ];
     do
       read ANS
@@ -67,18 +63,18 @@ setup() {
               break
               ;;
           n|N)
-              echo "一括制御のセットアップを中止します。"
+              echo "The setup of the collective run function is discontinued."
               sleep 1
               return
               ;;
           *)
-              echo "Y か N を入力して下さい。"
+              echo "Please input Y or N."
               ;;
       esac
     done
 
     if [ -e ${HOME}/.ssh/id_rsa.pub ]; then
-        echo "既に公開鍵が存在します。"
+        echo "The public key already exists."
         sleep 1
         return
     fi
@@ -97,22 +93,22 @@ setup() {
 
     if [ $? -ne 0 ] ; then
         echo ""
-        echo "公開鍵の作成に失敗しました。"
+        echo "It failed in making the public key."
         echo ""
         break
     fi
 
     echo ""
-    echo "公開鍵を作成しました。"
+    echo "The public key was made."
     echo ""
 }
 
 
-#監視対象ノードへのJBoss起動ユーザの公開鍵の登録
+# Registration of JBoss start user's public key to node for monitoring
 entry() {
     if [ ! -e ${HOME}/.ssh/id_rsa.pub ]; then
         echo ""
-        echo "${HINEMOS_JBOSS_USER} ユーザの公開鍵が作成されていません。作成して下さい。"
+        echo "${HINEMOS_JBOSS_USER} user's public key is not made. Please make it."
         return
     fi
     
@@ -120,13 +116,13 @@ entry() {
 
     echo ""
     echo ""
-    echo "監視対象ノードの${REMOTE_USER}ユーザのauthorized_keysファイルに、${HINEMOS_JBOSS_USER} ユーザの公開鍵を登録します。"
+    echo "${HINEMOS_JBOSS_USER} user's public key is registered in the ${REMOTE_USER} user's with node for the authorized_keys file."
 
     while [ 1 ];
     do
         echo ""
-        echo "一括制御機能を利用する監視対象ノードのIPアドレスを入力して下さい。"
-        echo "終了する場合は、9を入力して下さい。"
+        echo "Please input IP address of the node that uses the collective run function for the monitoring."
+        echo "Please input 9 when ending."
         
         read AGENT_IP
         
@@ -139,14 +135,14 @@ entry() {
     
      	    if [ $? -ne 0 ] ; then
 		echo ""
-		echo "${AGENT_IP} は存在しません。"
+		echo "${AGENT_IP} doesn't exist."
 
 	    else
 		echo ""
-		echo "監視対象ノードの${REMOTE_USER}ユーザのホームディレクトリを指定して下さい。"
+		echo "Please specify the home directory of the ${REMOTE_USER} user with the node for the monitoring."
 		read ROOT_HOME
 		
-	    #末尾が/でなかったら追加する
+	    # When the end is not "/", it adds it. 
 		case ${ROOT_HOME} in
 		    */)
 		        ;;
@@ -155,8 +151,8 @@ entry() {
 			;;
 		esac
 		
-		echo ${ROOT_HOME}".ssh/authorized_keysに、${HINEMOS_JBOSS_USER} ユーザの公開鍵を設定します。"
-		echo "よろしいですか? (Y/N default:Y)"
+		echo "${HINEMOS_JBOSS_USER} user's public key is set to ${ROOT_HOME}.ssh/authorized_keys."
+		echo "Is it good? (Y/N default:Y)"
 		read ANS
 		ANS=${ANS:-Y}
 		AGENT_AUTHORIZED_KEYS=${ROOT_HOME}.ssh/authorized_keys
@@ -172,7 +168,7 @@ entry() {
                         "
 
 			echo ""
-			echo "${AGENT_IP} への登録が完了しました。"
+			echo "Registration to ${AGENT_IP} was completed."
 		        ;;
 		    n|N)
    		        ;;
@@ -188,15 +184,15 @@ entry() {
 
 
 
-# main処理
+# Main Function
 while [ 1 ];
 do
     echo ""
-    echo "一括制御機能のセットアップ"
+    echo "the Setup of the collective run function"
     echo ""
-    echo "     1) ${HINEMOS_JBOSS_USER}ユーザの認証用の公開鍵の作成"
-    echo "     2) 監視対象ノードへの公開鍵登録"
-    echo "     9) 一括制御機能のセットアップ終了"
+    echo "     1) Making of public key for attestation of ${HINEMOS_JBOSS_USER} user"
+    echo "     2) Public key registration to node for monitoring"
+    echo "     9) Setup end of collective run function"
     echo ""
     echo -n "===> "
 
