@@ -117,13 +117,13 @@ function clean_jbm_table {
 # remove jta transaction files
 #
 function clean_tx_files {
-	if [ ! -e ${JBOSS_HOME}/server/default/data/tx-object-store ]
+	if [ ! -e ${JBOSS_HOME}/server/hinemos/data/tx-object-store ]
 	then
 		Logging "${MSG_I009}"
 		return 0
 	fi
 	
-	MSG=`rm -rf ${JBOSS_HOME}/server/default/data/tx-object-store`
+	MSG=`rm -rf ${JBOSS_HOME}/server/hinemos/data/tx-object-store`
 	RET=$?
 	if [ ${RET} -ne 0 ]
 	then
