@@ -60,9 +60,9 @@ MSG_E002="no argument specified."
 # show usage
 #
 function usage() {
-	echo "usage : ${PROG} [options] [-c|-C|-e|-E|-j|-J|-S|-v|-V|-p CollectorId|-P]"
+	echo "usage : ${PROG} [options] [-c|-C|-e|-E|-j|-J|-S|-v|-V|-p MonitorId|-P]"
 	echo "options:"
-	echo "  -r day     specify retention period (performance data only)"
+	echo "  -r day     specify retention period (performance data only. with -p or -P option)"
 	echo "  -w passwd  set password (for Hinemos RDBM Server)"
 	echo "command:"
 	echo "  -c              remove collective-run histories which is already done."
@@ -74,7 +74,7 @@ function usage() {
 	echo "  -S              remove all status."
 	echo "  -v              remove vm operation histories which is already done."
 	echo "  -V              remove all vm operation history."
-	echo "  -p CollectorId  remove performance data."
+	echo "  -p MonitorId    remove performance data."
 	echo "  -P              remove all performance data."
 }
 
@@ -118,7 +118,7 @@ do
 			;;
 		p)
 			ARGS="${ARGS} p"
-			COLLECTOR_ID=$OPTARG
+			MONITOR_ID=$OPTARG
 			;;
 		P)
 			ARGS="${ARGS} P"
@@ -246,22 +246,18 @@ COMMIT;
 DML`
 			;;
 		p)
-			SQL_EXEC_MSG="${MSG_I010} CollectorId=${COLLECTOR_ID}"
+			SQL_EXEC_MSG="${MSG_I010} MonitorId=${MONITOR_ID}"
 			if [ "x"${START_DATE} = "x" ]
 			then
 				SQL=`cat <<DML
 BEGIN;
-UPDATE cc_collector_profile SET start_date = (SELECT max(date_time) FROM cc_calculated_data WHERE collectorid = '${COLLECTOR_ID}') WHERE collectorid = '${COLLECTOR_ID}' AND EXISTS (SELECT * FROM cc_calculated_data WHERE collectorid = '${COLLECTOR_ID}');
-DELETE FROM cc_calculated_data WHERE collectorid = '${COLLECTOR_ID}';
-UPDATE cc_collector_status SET count = (SELECT count(*) FROM (SELECT date_time FROM cc_calculated_data WHERE collectorid = '${COLLECTOR_ID}' GROUP BY date_time) A) WHERE collectorid = '${COLLECTOR_ID}';
+DELETE FROM cc_calculated_data WHERE collectorid = '${MONITOR_ID}';
 COMMIT;
 DML`
 			else
 				SQL=`cat <<DML
 BEGIN;
-DELETE FROM cc_calculated_data WHERE collectorid = '${COLLECTOR_ID}' and date_time < '${START_DATE}';
-UPDATE cc_collector_profile SET start_date = (SELECT min(date_time) AS older_date_time FROM cc_calculated_data WHERE collectorid = '${COLLECTOR_ID}') WHERE collectorid = '${COLLECTOR_ID}' AND EXISTS (SELECT * FROM cc_calculated_data WHERE collectorid = '${COLLECTOR_ID}');
-UPDATE cc_collector_status SET count = (SELECT count(*) FROM (SELECT date_time FROM cc_calculated_data WHERE collectorid = '${COLLECTOR_ID}' GROUP BY date_time) A) WHERE collectorid = '${COLLECTOR_ID}';
+DELETE FROM cc_calculated_data WHERE collectorid = '${MONITOR_ID}' and date_time < '${START_DATE}';
 COMMIT;
 DML`
 			fi
@@ -273,17 +269,12 @@ DML`
 				SQL=`cat <<DML
 BEGIN;
 TRUNCATE TABLE cc_calculated_data;
-UPDATE cc_collector_status SET count = 0;
 COMMIT;
 DML`
 			else
 				SQL=`cat <<DML
 BEGIN;
 DELETE FROM cc_calculated_data WHERE date_time < '${START_DATE}';
-
-CREATE TEMPORARY TABLE tmp_calcdata_summay AS SELECT collectorid, count(collectorid), min(date_time) AS older_date_time FROM (SELECT collectorid, date_time FROM cc_calculated_data GROUP BY collectorid, date_time ORDER BY collectorid) A GROUP BY collectorid;
-UPDATE cc_collector_status B SET count = A.count FROM tmp_calcdata_summay AS A WHERE A.collectorid = B.collectorid;
-UPDATE cc_collector_profile B SET start_date = A.older_date_time FROM tmp_calcdata_summay AS A WHERE A.collectorid = B.collectorid;
 COMMIT;
 DML`
 			fi
