@@ -17,7 +17,7 @@ SUMMARY_FILE="/opt/hinemos/var/log/hinemos_manager_summary.${FILENAME_POSTFIX}"
 echo ""
 echo ""
 echo "#################################################"
-echo "### Hinemos   stats collect script (20110701) ###"
+echo "### Hinemos   stats collect script (20120401) ###"
 echo "###    Script start at `date '+%Y-%m-%d %T'`    ###"
 echo "#################################################"
 echo ""
@@ -71,13 +71,19 @@ case ${VER_MJ} in
     COLUMN_COLLECTOR_PROFILE_INTERVAL="interval_sec"
     VALUE_TRIGGER_NAME_PROCESS="MON_PRC"
     ;;
-    '3.2' | *)
+    '3.2')
     PG_FACILITY="true"
     TABLE_COLLECTOR_PROFILE="cc_collector_profile"
     TABLE_CALCULATED_DATA="cc_calculated_data"
     COLUMN_COLLECTOR_PROFILE_INTERVAL="interval_sec"
     VALUE_TRIGGER_NAME_PROCESS="MON_PRC"
     ;;
+    '4.0')
+    PG_FACILITY="true"
+    TABLE_CALCULATED_DATA="cc_calculated_data"
+    COLUMN_COLLECTOR_PROFILE_INTERVAL="interval_sec"
+    VALUE_TRIGGER_NAME_PROCESS="MON_PRC"
+    ;;
     '2.0' | '2.1' | '2.2' | '2.3')
     echo "This script does not support Hinemos ${VER}" 1>&2
     echo "VER=${VER}, VER_MJ=${VER_MJ}"
@@ -197,6 +203,7 @@ ${PSQLCMD} -c "
 " | tee -a ${SUMMARY_FILE}
 
 ## "resource management" summary (collector_profile)
+if [ ${VER_MJ} != '4.0' ]; then
 echo "### collector_profile summary ###" | tee -a ${SUMMARY_FILE}
 ${PSQLCMD} -c "
     SELECT
@@ -219,9 +226,10 @@ ${PSQLCMD} -c "
         type,
         ${COLUMN_COLLECTOR_PROFILE_INTERVAL}
 " | tee -a ${SUMMARY_FILE}
-
+fi
 
 ## Syslog-ng/SNMPTrap filter count
+if [ ${VER_MJ} != '4.0' ]; then
 echo "### Syslog-ng/SNMP-TRAP filter summary ###" | tee -a ${SUMMARY_FILE}
 ${PSQLCMD} -c "
     SELECT
@@ -242,6 +250,7 @@ ${PSQLCMD} -c "
     GROUP BY
         valid_flg
 " | tee -a ${SUMMARY_FILE}
+fi
 
 ## JOB-net
 echo "### Job-net summary ###" | tee -a ${SUMMARY_FILE}
@@ -263,13 +272,25 @@ ${PSQLCMD} -c "
         job_type
 " | tee -a ${SUMMARY_FILE}
 
+## running job
+echo "### Running Job count ###" | tee -a ${SUMMARY_FILE}
+${PSQLCMD} -c "
+    SELECT count(*)
+    FROM
+        cc_job_session s, cc_job_session_job j
+    WHERE
+        s.session_id = j.session_id AND s.jobunit_id = j.jobunit_id AND
+         s.job_id = j.job_id AND status NOT IN (300,301)
+" | tee -a ${SUMMARY_FILE}
+
+
 ## log table size
 echo "### log table summary ###" | tee -a ${SUMMARY_FILE}
 ${PSQLCMD} -c "
     SELECT
         relname,
         reltuples,
-        pg_relation_size(relname)
+        pg_relation_size(relname::regclass)
     FROM
         pg_class
     WHERE
@@ -290,7 +311,7 @@ ${PSQLCMD} -c "
     SELECT
         relname,
         reltuples,
-        pg_relation_size(relname)
+        pg_relation_size(relname::regclass)
     FROM
         pg_class
     WHERE
@@ -339,6 +360,25 @@ echo "NIC        : ${NIC}" | tee -a ${SUMMARY_FILE}
 echo "FileSystem : ${FS}" | tee -a ${SUMMARY_FILE}
 echo "" | tee -a ${SUMMARY_FILE}
 
+if [ "x${PG_FACILITY}" = "xtrue" ]
+then
+    echo "### Node Platform ###" | tee -a ${SUMMARY_FILE}
+    ${PSQLCMD} -c "
+        SELECT
+            platform_family,
+            virtualization_node_type,
+            virtualization_solution,
+            count(*) count
+        FROM
+            cc_cfg_node
+        GROUP BY
+            platform_family,
+            virtualization_node_type,
+            virtualization_solution
+        ORDER BY
+            count DESC;
+    " | tee -a ${SUMMARY_FILE}
+fi
 
 ## pg_stat_database
 echo "### pg_stat_database ###" | tee -a ${SUMMARY_FILE}
@@ -357,7 +397,8 @@ ${PSQLCMD} -c "
     FROM
         pg_stat_user_tables
     ORDER BY
-        relname
+        seq_scan + seq_tup_read + idx_scan + idx_tup_fetch + n_tup_ins +
+        n_tup_upd + n_tup_del + n_tup_hot_upd + n_live_tup + n_dead_tup DESC
 " | tee -a ${SUMMARY_FILE}
 
 ## pg_stat_user_indexes
@@ -368,7 +409,7 @@ ${PSQLCMD} -c "
     FROM
         pg_stat_user_indexes
     ORDER BY
-        relname
+        idx_scan + idx_tup_read + idx_tup_fetch DESC
 " | tee -a ${SUMMARY_FILE}
 
 ## pg_staiot_user_tables
@@ -379,7 +420,7 @@ ${PSQLCMD} -c "
     FROM
         pg_statio_user_tables
     ORDER BY
-        relname
+        heap_blks_read + heap_blks_hit + idx_blks_read + idx_blks_hit DESC
 " | tee -a ${SUMMARY_FILE}
 
 ## pg_statio_user_indexes
@@ -390,7 +431,7 @@ ${PSQLCMD} -c "
     FROM
         pg_statio_user_indexes
     ORDER BY
-        relname
+        idx_blks_read + idx_blks_hit DESC
 " | tee -a ${SUMMARY_FILE}
 
 
@@ -513,7 +554,7 @@ echo -e "\n" | tee -a ${SUMMARY_FILE}
 ## md5sum
 echo "### md5sum ###" | tee -a ${SUMMARY_FILE}
 cd ${HINEMOS_HOME}
-find `ls --ignore='var'` -type f | xargs md5sum | tee -a ${SUMMARY_FILE}
+find `ls --ignore='var'` -type f -print0 | xargs -0 md5sum | tee -a ${SUMMARY_FILE}
 cd -
 echo -e "\n" | tee -a ${SUMMARY_FILE}
 }
